@@ -14,10 +14,11 @@ class DiscreteNoiseBuilder:
         self.num_discrete_values = num_discrete_values
         return self
 
-    def build(self) -> DiscreteNoise:
-        signal = self.signal_to_noise_ratio
-        num_noise_classes = self.num_discrete_values - 1
-        avg_noise = (1 - signal) / num_noise_classes
-        probs = [signal] + [avg_noise for _ in range(num_noise_classes)]
+    def build(self) -> DiscreteNoise:      
+        # Signal_noise = portions of uniform noise over all discrete values, i.e., signal_to_noise_ratio=0 for no noise and signal_to_noise_ratio =1 for uniform noise
+        signal_noise = self.signal_to_noise_ratio / self.num_discrete_values
+        
+        # Probabilities
+        probs = [(1-self.signal_to_noise_ratio)+signal_noise] + [(signal_noise) for _ in range(self.num_discrete_values - 1)]
 
         return DiscreteNoise(prob_distribution=CustomDiscreteDistribution(probs=probs))
